@@ -25,9 +25,11 @@
 #'
 #' @name getEdges
 #'
-#' @details When \code{ingraph=TRUE}: If type="decomposable" then
-#'     \code{getEdges()} returns those edges e for which the graph with e
-#'     removed is decomposable.
+#' @details
+#'
+#' When \code{ingraph=TRUE}: If type="decomposable" then
+#' \code{getEdges()} returns those edges e for which the graph with e
+#' removed is decomposable.
 #' 
 #' When \code{ingraph=FALSE}: Likewise, if type="decomposable" then
 #' \code{getEdges()} returns those edges e for which the graph with e added is
@@ -44,6 +46,7 @@
 #' 
 #' @aliases getEdges getEdges.list getEdges.graphNEL getEdges.matrix getInEdges
 #'     getOutEdges getEdgesMAT getInEdgesMAT getOutEdgesMAT
+#' 
 #' @param object An object representing a graph; either a generator list, a
 #'     graphNEL object or an adjacency matrix.
 #' @param type Either "unrestricted" or "decomposable"
@@ -111,31 +114,40 @@
 #' ## would create a forbidden path; a path with only continuous vertices
 #' ## between two discrete vertices.
 #' 
-#' 
+ 
 #' @export getEdges
 getEdges <- function(object, type="unrestricted", ingraph=TRUE, discrete=NULL, ...){
-  UseMethod("getEdges")
+    UseMethod("getEdges")
 }
 
-getEdges.list <- function(object, type="unrestricted", ingraph=TRUE, discrete=NULL, ...){
-    getEdgesMAT(glist2adjMAT(object), type=type, ingraph=ingraph, discrete=discrete, ...)
+#' @export
+getEdges.iModel <- function(object, type="unrestricted", ingraph=TRUE, discrete=NULL, ...){
+    getEdgesMAT(glist2adjMAT(terms(object)), type=type, ingraph=ingraph, discrete=discrete, ...)
 }
 
+#' @export
 getEdges.graphNEL <- function(object, type="unrestricted", ingraph=TRUE, discrete=NULL, ...){
     getEdgesMAT(as.adjMAT(object), type=type, ingraph=ingraph, discrete=discrete, ...)
 }
 
+#' @export
+getEdges.list <- function(object, type="unrestricted", ingraph=TRUE, discrete=NULL, ...){
+    getEdgesMAT(glist2adjMAT(object), type=type, ingraph=ingraph, discrete=discrete, ...)
+}
+
+#' @export
 getEdges.matrix <- function(object, type="unrestricted", ingraph=TRUE, discrete=NULL, ...){
     getEdgesMAT(object, type=type, ingraph=ingraph, discrete=discrete, ...)    
 }
 
-
+#' @export
 getInEdges <- function(object, type="unrestricted", discrete=NULL, ...){
-  getEdges(object, type=type, ingraph=TRUE, discrete=discrete, ...)
+    getEdges(object, type=type, ingraph=TRUE, discrete=discrete, ...)
 }
 
+#' @export
 getOutEdges <- function(object, type="unrestricted", discrete=NULL, ...){
-  getEdges(object, type=type, ingraph=FALSE, discrete=discrete, ...)
+    getEdges(object, type=type, ingraph=FALSE, discrete=discrete, ...)
 }
 
 
@@ -165,17 +177,17 @@ getInEdgesMAT <- function(adjmat, type="unrestricted", discrete=NULL, ...){
 }
 
 getOutEdgesMAT <- function(adjmat, type="unrestricted", discrete=NULL, ...){
-  type <- match.arg(type, c("unrestricted", "decomposable"))
-  emat <- nonEdgeListMAT(adjmat, matrix=TRUE)
-  if (type == "decomposable"){
-      idx <- vector("logical", nrow(emat))    
-      for (ii in seq_len(nrow(emat))){
-        ed <- emat[ii,]
-        adjmat[ed[1], ed[2]] <- adjmat[ed[2], ed[1]] <- 1L
-        idx[ii] <- length(mcsmarkedMAT(adjmat, discrete=discrete)) > 0
-        adjmat[ed[1], ed[2]] <- adjmat[ed[2], ed[1]] <- 0L
-      }
-      emat <- emat[idx, , drop=FALSE]
+    type <- match.arg(type, c("unrestricted", "decomposable"))
+    emat <- nonEdgeListMAT(adjmat, matrix=TRUE)
+    if (type == "decomposable"){
+        idx <- vector("logical", nrow(emat))    
+        for (ii in seq_len(nrow(emat))){
+            ed <- emat[ii,]
+            adjmat[ed[1], ed[2]] <- adjmat[ed[2], ed[1]] <- 1L
+            idx[ii] <- length(mcsmarkedMAT(adjmat, discrete=discrete)) > 0
+            adjmat[ed[1], ed[2]] <- adjmat[ed[2], ed[1]] <- 0L
+        }
+        emat <- emat[idx, , drop=FALSE]
     }
-  emat
+    emat
 }
