@@ -4,7 +4,6 @@
 ##
 ##########################################################
 
-
 #' @title Graphical Gaussian model
 #' 
 #' @description Specification of graphical Gaussian model. The 'c' in the name
@@ -17,16 +16,19 @@
 #'     the variables.
 #' 
 #' @param formula Model specification in one of the following forms: 1) a
-#'     right-hand sided formula, 2) as a list of generators, 3) an undirected
-#'     graph (represented either as a graphNEL object or as an adjacency
-#'     matrix).  Notice that there are certain model specification shortcuts,
-#'     see Section 'details' below
+#'     right-hand sided formula, 2) as a list of generators.
+#'     Notice that there are certain model specification shortcuts,
+#'     see Section 'details' below.
+#' 
 #' @param data Data in one of the following forms: 1) A dataframe or 2) a list
 #'     with elements \code{cov} and \code{n.obs} (such as returned by the
 #'     \code{cov.wt()} function.)
+#'
 #' @param marginal Should only a subset of the variables be used in connection
-#'     with the model specification shortcuts
+#'     with the model specification shortcuts.
+#'
 #' @param fit Should the model be fitted.
+#'
 #' @param details Control the amount of output; for debugging purposes.
 #' @return An object of class \code{cModel} (a list)
 #' @author Søren Højsgaard, \email{sorenh@@math.aau.dk}
@@ -47,35 +49,28 @@
 #'  ncol=2))
 #' 
 #' @export cmod
+
 cmod <- function(formula, data, marginal=NULL, fit=TRUE, details=0){
 
-  if (inherits(data, "data.frame")){
-      tmp   <- cov.wt(data, method="ML")
-      S     <- tmp$cov
-      n.obs <- tmp$n.obs
-  } else {
-      S     <- data$cov
-      n.obs <- data$n.obs
-  }
-    
-    varNames <- colnames(S)
-    ans      <- .pFormula2(formula, varNames, marginal)
-    ##, v.sep = ":",  g.sep = "+", ignore.power.value=TRUE) 
-    glist <- ans$glist
+    dd <- .extract_cmod_data(data)
+
+    vn <- colnames(dd$S)
+    ans      <- parse_gm_formula(formula, vn, marginal)
     ## Get varNames in the order matching to the data:
-    varNames <- varNames[sort(match(ans$varNames, varNames))]
+    vn <- vn[sort(match(ans$varNames, vn))]
+
+    datainfo <- list(S=dd$S[vn, vn],
+                     n.obs=dd$n.obs,
+                     data=data)
     
-    datainfo <- list(S=S[varNames, varNames],
-                     n.obs=n.obs, data=data)
-    
-    res <- list(glist          = glist,
-                varNames       = varNames,
+    res <- list(glist          = ans$glist,
+                varNames       = vn,
                 datainfo       = datainfo,
                 fitinfo        = NULL,
                 isFitted       = FALSE
                 )
     
-    upd   <- .cModel_finalize(glist, varNames)  
+    upd   <- .cModel_finalize(ans$glist, vn)  
     res[names(upd)] <- upd  
     class(res) <- c("cModel", "iModel")
     
@@ -83,6 +78,21 @@ cmod <- function(formula, data, marginal=NULL, fit=TRUE, details=0){
 }
 
 
+.extract_cmod_data <- function(data){
+    if (inherits(data, "data.frame")){
+        data <- cov.wt(data, method="ML")
+    } else
+        if (inherits(data, "list") && identical(names(data), c("cov", "center", "n.obs"))){
+            ## OK
+        } else
+            stop("Can not proceed...")
+    
+            
+    names(data)[1] <- "S"
+    data
+}
+
+
 .cModel_finalize <- function(glist, varNames){
 
     amat   <- ugList(glist, result="matrix")
@@ -97,7 +107,7 @@ cmod <- function(formula, data, marginal=NULL, fit=TRUE, details=0){
     ret
 }
 
-
+#' @export
 fit.cModel <- function(object, engine="ggmfit",start=NULL, ...){
 
   switch(engine,
@@ -155,12 +165,49 @@ fit.cModel <- function(object, engine="ggmfit",start=NULL, ...){
 
 
 
+## cmod <- function(formula, data, marginal=NULL, fit=TRUE, details=0){
 
+##     if (inherits(data, "data.frame")){
+##         tmp   <- cov.wt(data, method="ML")
+##         S     <- tmp$cov
+##         n.obs <- tmp$n.obs
+##     } else {
+##         S     <- data$cov
+##         n.obs <- data$n.obs
+##     }
+    
+##     varNames <- colnames(S)
+##     ans      <- parse_gm_formula(formula, varNames, marginal)
+##     glist <- ans$glist
+##     ## Get varNames in the order matching to the data:
+##     varNames <- varNames[sort(match(ans$varNames, varNames))]
+    
+##     datainfo <- list(S=S[varNames, varNames],
+##                      n.obs=n.obs, data=data)
+    
+##     res <- list(glist          = glist,
+##                 varNames       = varNames,
+##                 datainfo       = datainfo,
+##                 fitinfo        = NULL,
+##                 isFitted       = FALSE
+##                 )
+    
+##     upd   <- .cModel_finalize(glist, varNames)  
+##     res[names(upd)] <- upd  
+##     class(res) <- c("cModel", "iModel")
+    
+##     if (fit) fit(res) else res
+## }
 
+##     ##, v.sep = ":",  g.sep = "+", ignore.power.value=TRUE) 
 
 
 
 
+# , 3) an undirected
+#      graph (represented either as a graphNEL object or as an adjacency
+#     matrix).  
+
 
 
 
