@@ -1,13 +1,15 @@
-
+#####################################################################
 #' @title General functions related to iModels
-#'
 #' @description General functions related to iModels
-#'
-#' @name iModel-general
+#' @name imodel-general
+#####################################################################
 #'
 #' @param object,fit,x An \code{iModel} object.
-#' 
-#' @rdname iModel-general
+#' @param scale Unused (and irrelevant for these models)
+#' @param k Weight of the degrees of freedom in the AIC formula
+#' @param ... Currently unused.
+
+#' @rdname imodel-general
 logLik.iModel <- function(object, ...){
     val <- object$fitinfo$logL
     attr(val, "df") <- unname( object$fitinfo$dimension["mod.dim"] )
@@ -17,35 +19,33 @@ logLik.iModel <- function(object, ...){
 }
 
 
-#' @rdname iModel-general
-#' @param scale Unused (and irrelevant for these models)
-#' @param k Weight of the degrees of freedom in the AIC formula
-#' @param ... Currently unused.
-#' 
+#' @rdname imodel-general
 extractAIC.iModel <- function(fit, scale, k = 2, ...){
     unname(c(fit$fitinfo$dimension["mod.dim"],
              -2*fit$fitinfo$logL + k*fit$fitinfo$dimension["mod.dim"]))
 }
 
-#' @rdname iModel-general
+#' @rdname imodel-general
 summary.iModel <- function(object, ...){
   glist <- getmi(object, "glist")
   isg   <- getmi(object, "isGraphical")
   isd   <- getmi(object, "isDecomposable")
 
   cq    <- getCliques(ugList(glist))# $maxCliques
-  ans   <- structure(list(glist=glist, isGraphical=isg, isDecomposable=isd, cliques=cq),
+  ans   <- structure(list(glist=glist, isGraphical=isg, isDecomposable=isd,
+                          cliques=cq),
                      class="iModelsummary")
   ans
 }
 
-#' @rdname iModel-general
+#' @rdname imodel-general
 print.iModelsummary <- function(x,...){
-  cat(sprintf("is graphical=%s; is decomposable=%s\n", x$isGraphical, x$isDecomposable))
-  cat("generators (glist):\n")
-  str(x$glist, give.head=FALSE, comp.str=" ", no.list=TRUE)
-  #cat("EXPERIMENTAL: components: ", names(x),"\n")
-  invisible(x)
+    cat(sprintf("is graphical=%s; is decomposable=%s\n",
+                x$isGraphical, x$isDecomposable))
+    cat("generators (glist):\n")
+    str(x$glist, give.head=FALSE, comp.str=" ", no.list=TRUE)
+    ##cat("EXPERIMENTAL: components: ", names(x),"\n")
+    invisible(x)
 }
 
 .extractFIT <- function(object,...){
@@ -53,42 +53,46 @@ print.iModelsummary <- function(x,...){
 }
 
 .glist2formula <- function (f) {
-  if (inherits(f, "formula"))
-    return(f)
-  ans <- try(as.formula(paste("~", paste(unlist(lapply(f, paste, collapse = "*")),
-                                         collapse = "+")), .GlobalEnv),silent=TRUE)
-  if (inherits(ans, "try-error"))
-    stop("Unable to create formula from list. \nCould be due to white space, strange characters etc. in variable names\n")
-  ans
+    if (inherits(f, "formula"))
+        return(f)
+    ans <- try(as.formula(paste("~", paste(unlist(lapply(f, paste, collapse = "*")),
+                                           collapse = "+")), .GlobalEnv),silent=TRUE)
+    if (inherits(ans, "try-error"))
+        stop("Unable to create formula from list. \nCould be due to white space, strange characters etc. in variable names\n")
+    ans
 }
 
-#' @rdname iModel-general
+#' importFrom stats formula terms
+
+#' @export
+#' @rdname imodel-general
 formula.iModel <- function(x,...){
-	#list2rhsFormula(x$glist)
-  .glist2formula(x$glist)
+    .glist2formula(x$glist)
 }
 
-#' @rdname iModel-general
+#' @export
+#' @rdname imodel-general
 terms.iModel <- function(x, ...){
-	x$glist
+    x$glist
 }
 
-#' @rdname iModel-general
+
+#' @rdname imodel-general
 isGraphical.dModel <- function(x){
-    gRbase::isGraphical.default( terms(x) )
+    isGraphical( terms(x) )
 }
 
-#' @rdname iModel-general
+#' @rdname imodel-general
 isDecomposable.dModel <- function(x){
-    gRbase::isDecomposable.default( terms(x) )
+    isDecomposable( terms(x) )
 }
 
-#' @rdname iModel-general
+#' @rdname imodel-general
 modelProperties <- function(object){
     UseMethod("modelProperties")
 }
 
-#' @rdname iModel-general
+#' @rdname imodel-general                                 
 modelProperties.dModel <- function(object){
     x <- terms( object )
     vn <- unique(unlist(x))
